function YearlyVariables=Diff2AnnualDiff(Variables,InitialValues,Season)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% PURPOSE:      Converts variables in differences to Season:th differences. Example: converts quarterly growth rates to annual
%
% INPUT:        Variables       (NObs-by-NVariables)        Variables to be transformed.           
%               InitialValues   ((Season-1)-by-NVariables)  Matrix of initial values, i.e. values on variables preceeding the
%                                                               observations in Variables.
%               Season          (Scalar)                    The season in Variables
%
% OUTPUT:       YearlyVariables (NObs-by-NVariables)        Transformed Variables.
%
% AUTHOR:       Mattias Villani, Research Department, Sveriges Riksbank and
%               Department of Statistics, Stockholm University. 
%               E-mail: mattias.villani@riksbank.se
%
% REVISED:      2004-08-26
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Converts variables in differences to fourth differences. 

p=size(Variables,2);
if size(InitialValues,1)==0
    InitialValues=[nan*ones(Season-1,p)];
end

Variables=[InitialValues;Variables];
[T,p]=size(Variables);
TRemain=T-Season+1;
YearlyVariables=zeros(TRemain,p);

for i=1:TRemain
    YearlyVariables(i,:)=sum(Variables(i:i+Season-1,:));
end


