function LogDensity=DensMultiT(x,mu,Sigma,df)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% PURPOSE:     Density for the k-variate student-t distribution with mean mu, covariance matrix
%              Sigma/(df-2) and df degrees of freedom
%
% INPUT:       mu       (k-by-1)        
%              Sigma    (k-by-k)            
%              df       (Scalar)            
%
% OUTPUT:      T        (k-by-1)    A draw from the multivariate student-t.          
%
% AUTHOR:      Mattias Villani, Research Department, Sveriges Riksbank and
%              Department of Statistics, Stockholm University. 
%              E-mail: mattias.villani@riksbank.se
%
% REVISED:     2005-11-03
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

x=x(:);
mu=mu(:);
k=length(mu);
P=inv(Sigma)/df; % Bauwens et al: (df-2);
LogCt=gammaln(df/2)-gammaln((df+k)/2)+(k/2)*log(pi)-0.5*log(det(P));
LogDensity=-LogCt-((df+k)/2)*log(1+(x-mu)'*P*(x-mu));